define(["require", "exports", "../Teams", "./Animator"], function (require, exports, Teams_1, Animator_1) {
    "use strict";
    Object.defineProperty(exports, "__esModule", { value: true });
    exports.Actions = void 0;
    /**
     * Animator for teams' actions.
     */
    class Actions extends Animator_1.Animator {
        /**
         * Runs a team's action.
         *
         * @param teamAction    Action with the team that wants to execute it.
         * @param onComplete   Callback for when this is done.
         * @type TAction   Type of action being performed.
         */
        run(teamAction, onComplete) {
            if (this.battleInfo.teams[Teams_1.Team[teamAction.source.team]].selectedActor !==
                teamAction.source.actor) {
                onComplete();
                return;
            }
            const animations = teamAction.source.team === Teams_1.Team.opponent
                ? this.animations.opponent
                : this.animations.player;
            switch (teamAction.action.type) {
                case "flee":
                    animations.actions.flee(teamAction, onComplete);
                    break;
                case "item":
                    animations.actions.item(teamAction, onComplete);
                    break;
                case "move":
                    animations.actions.move(teamAction, onComplete);
                    break;
                case "switch":
                    animations.switching.switch(teamAction, onComplete);
                    break;
                default:
                    throw new Error(`Unkown action: '${teamAction.action.type}'.`);
            }
        }
    }
    exports.Actions = Actions;
});
//# sourceMappingURL=Actions.js.map