define(["require", "exports", "../Teams", "./Actions", "./Animator", "./Introductions", "./Queue"], function (require, exports, Teams_1, Actions_1, Animator_1, Introductions_1, Queue_1) {
    "use strict";
    Object.defineProperty(exports, "__esModule", { value: true });
    exports.Main = void 0;
    /**
     * Root animator for a battle.
     */
    class Main extends Animator_1.Animator {
        /**
         * Initializes a new instance of the Animator class.
         *
         * @param settings   Settings to be used for initialization.
         * @param actionsOrderer   Battle info for the battle.
         */
        constructor(settings, actionsOrderer) {
            super(settings);
            /**
             * Animator for teams' actions.
             */
            this.actions = new Actions_1.Actions(this);
            /**
             * Animator for teams introducing themselves.
             */
            this.introductions = new Introductions_1.Introductions(this);
            this.actionsOrderer = actionsOrderer;
        }
        /**
         * Starts the battle's gameplay.
         */
        run() {
            const queue = new Queue_1.Queue();
            queue.add((next) => {
                this.animations.start(next);
            });
            queue.add((next) => {
                this.introductions.run(next);
            });
            queue.run(() => {
                this.waitForActions();
            });
        }
        /**
         * Waits for actions from each team's selector.
         */
        waitForActions() {
            const actions = {};
            let completed = 0;
            const onChoice = () => {
                completed += 1;
                if (completed === 2) {
                    this.executeActions(actions);
                }
            };
            this.battleInfo.teams.opponent.selector.nextAction(this.battleInfo, Teams_1.Team.opponent, (action) => {
                actions[Teams_1.Team[Teams_1.Team.opponent]] = action;
                onChoice();
            });
            this.battleInfo.teams.player.selector.nextAction(this.battleInfo, Teams_1.Team.player, (action) => {
                actions[Teams_1.Team[Teams_1.Team.player]] = action;
                onChoice();
            });
        }
        /**
         * Executes each team's chosen actions.
         *
         * @param actions   Chosen actions by the teams.
         */
        executeActions(actions) {
            const queue = new Queue_1.Queue();
            for (const action of this.actionsOrderer(actions)) {
                queue.add((next) => {
                    this.actions.run(action, next);
                });
            }
            queue.run(() => {
                this.waitForActions();
            });
        }
    }
    exports.Main = Main;
});
//# sourceMappingURL=Main.js.map