define(["require", "exports"], function (require, exports) {
    "use strict";
    Object.defineProperty(exports, "__esModule", { value: true });
    exports.Queue = void 0;
    /**
     * Queues callbacks to be run.
     */
    class Queue {
        constructor() {
            /**
             * Callbacks waiting to be run.
             */
            this.queuedCallbacks = [];
        }
        /**
         * Queues an callback, if it exists.
         *
         * @param callback   A callback that may or may not exist.
         */
        add(callback) {
            if (callback !== undefined) {
                this.queuedCallbacks.push(callback);
            }
        }
        /**
         * Runs the queued animations.
         *
         * @param onComplete   Handler for when animations are done.
         */
        run(onComplete) {
            const callback = this.queuedCallbacks.shift();
            if (callback !== undefined) {
                callback(() => {
                    this.run(onComplete);
                });
            }
            else {
                onComplete();
            }
        }
        /**
         * Removes any pending queued callbacks.
         */
        clear() {
            this.queuedCallbacks.length = 0;
        }
    }
    exports.Queue = Queue;
});
//# sourceMappingURL=Queue.js.map